﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;

namespace WindowsFormsApplication7
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }       

        private void Form1_Load(object sender, EventArgs e)
        {
            DataTable dt = DummyDataCreator.GetData(10, new Type[] { typeof(int), typeof(int), typeof(int), typeof(int), typeof(int), typeof(int), typeof(int), typeof(int), typeof(int), typeof(int), typeof(int) });
            dt.Columns[11].ColumnName = "Type";

            foreach (DataRow row in dt.Rows)
            {
                row["Type"] = DummyDataCreator.RandomInt(1, 2);
            }
            dt.AcceptChanges();

            this.ultraGrid1.SetDataBinding(dt, null);

            this.ultraGrid1.CreationFilter = new SummaryCreationFilter();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            UltraGridLayout layout = e.Layout;
            UltraGridOverride ov = layout.Override;
            UltraGridBand band = layout.Bands[0];

            layout.ViewStyleBand = ViewStyleBand.OutlookGroupBy;
            band.SortedColumns.Add("Type", false, true);
            ov.SummaryDisplayArea = SummaryDisplayAreas.GroupByRowsFooter | SummaryDisplayAreas.Bottom;

            foreach (UltraGridColumn column in band.Columns)
            {
                if (column.Key.StartsWith("Int32 "))
                {
                    band.Summaries.Add("Summary: " + column.Key, SummaryType.Sum, column);
                }
            }
        }
    }

    public class SummaryCreationFilter : IUIElementCreationFilter
    {
        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            // FixedSummaryLineUIElement is the element that contains the SummaryValueUIElements.
            if (parent is FixedSummaryLineUIElement)
            {
                // Keep a list of elements we want to remove. This is so we can remove them all at once
                // instead of removing the element while we are in a foreach loop. 
                List<UIElement> elementsToRemove = new List<UIElement>();

                foreach (UIElement element in parent.ChildElements)
                {
                    // Find the SummaryValueUIElements and ignore any other elements. 
                    SummaryValueUIElement summaryValueUIElement = element as SummaryValueUIElement;
                    if (null == element)
                        continue;

                    // Get the summaryValue object and the rows collection to which is belongs. 
                    SummaryValue summaryValue = summaryValueUIElement.SummaryValue;
                    RowsCollection parentRows = summaryValue.ParentRows;
                    
                    // So if the rows collection is the child of a GroupByRow. 
                    UltraGridGroupByRow groupByRow = parentRows.ParentRow as UltraGridGroupByRow;
                    if (null != groupByRow)
                    {
                        // Get the value of the GroupByRow. 
                        int value = (int)groupByRow.Value;
                        
                        // Use the summary key and the groupByRow's value to determine which summaries
                        // should not be displayed. 
                        switch (summaryValue.Key)
                        {   
                            case "Summary: Int32 1":
                            case "Summary: Int32 2":
                            case "Summary: Int32 3":
                            case "Summary: Int32 4":
                            case "Summary: Int32 5":
                                if (value == 1)
                                    elementsToRemove.Add(element);

                                break;
                            
                            case "Summary: Int32 6":
                            case "Summary: Int32 7":
                            case "Summary: Int32 8":
                            case "Summary: Int32 9":
                            case "Summary: Int32 10":
                                if (value == 2)
                                    elementsToRemove.Add(element);
                                break;                           
                            
                        }
                    }
                }

                // Remove all of the elemnts that we marked or removal. 
                foreach (UIElement elementToRemove in elementsToRemove)
                {
                    parent.ChildElements.Remove(elementToRemove);
                }
            }
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }

}
